@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: mnemo/search.php,v 1.9.8.5 2007/01/02 13:55:11 jan Exp $
+ * $Horde: mnemo/search.php,v 1.9.8.8 2009/01/06 15:24:57 jan Exp $
  *
- * Copyright 2001-2007 Jon Parise <jon@horde.org>
+ * Copyright 2001-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -15,7 +15,10 @@
 @define('MNEMO_BASE', dirname(__FILE__));
 require_once MNEMO_BASE . '/lib/base.php';
 $title = _("Search");
+$notification->push('document.getElementById(\'search_pattern\').focus();', 'javascript');
+Horde::addScriptFile('prototype.js', 'mnemo', true);
 require MNEMO_TEMPLATES . '/common-header.inc';
 require MNEMO_TEMPLATES . '/menu.inc';
 require MNEMO_TEMPLATES . '/search/search.inc';
+require MNEMO_TEMPLATES . '/panel.inc';
 require $registry->get('templates', 'horde') . '/common-footer.inc';
